def is_it_dictionary(data):
    return isinstance(data, dict)


def is_it_string(data):
    return isinstance(data, str)


def is_it_list(data):
    return isinstance(data, list)


def is_it_integer(data):
    return isinstance(data, int)


def is_it_float(data):
    return isinstance(data, float)


